package info.textgrid.middleware;

import java.io.IOException;
import java.text.ParseException;
import javax.xml.datatype.DatatypeConfigurationException;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import info.textgrid.middleware.oaipmh.ListRecordsType;
import info.textgrid.middleware.oaipmh.MetadataType;
import info.textgrid.middleware.oaipmh.RecordType;

/**
 * @author Maximilian Brodhun, SUB Göttingen
 * @author Stefan E. Funk, SUB Göttingen
 * @version 2021-07-23
 * @since 2020-06-13
 */
public class RecordListDelivererDATACITE extends RecordListDelivererAbstract {

  private static Log log = LogFactory.getLog(RecordListDelivererDATACITE.class);

  /**
   * @param textgrid
   * @param dariah
   */
  public RecordListDelivererDATACITE(boolean textgrid, boolean dariah) {
    super(textgrid, dariah);
  }

  /**
   * @param recordList
   * @param set
   * @param headerIdentifier
   * @return
   */
  public RecordType buildRecord(ListRecordsType recordList, String set, String headerIdentifier) {

    MetadataType metadata = new MetadataType();
    RecordType record = new RecordType();

    record.setMetadata(metadata);
    recordList.getRecord().add(record);

    return null;
  }

  /*
   * (non-Javadoc)
   * 
   * @see info.textgrid.middleware.RecordListDelivererInterface#getRecords(java.lang.String,
   * java.lang.String, java.lang.String, java.lang.String)
   */
  public ListRecordsType getRecords(String from, String to, String set, String resumptionToken)
      throws ParseException, IOException {

    ListRecordsType openAireRecordList = new ListRecordsType();

    // Create one RecordDeliverer only, to configure all fields only ONCE.
    // FIYME May be solved using spring configuration, but I do not know how!
    RecordDelivererDATACITE openAireRecord =
        new RecordDelivererDATACITE(this.textgrid, this.dariah);
    // Must be done here, as spring does not configure this bean if instantiated with "new".
    openAireRecord.setConfigFileProps();

    for (String uri : getUriList(from, to, set, resumptionToken)) {

      log.debug("uri: " + uri);

      String eventuallyChangedUri = uri;

      // **
      // TextGrid
      // **

      if (this.textgrid) {
        // We must remove the prefix, as ElasticSearch is storing the IDs without it.
        eventuallyChangedUri = uri.replace("textgrid:", "");
      }

      // **
      // DARIAH
      // **

      else if (this.dariah) {
        eventuallyChangedUri = uri;
      }

      log.debug("eventuallyChangedUri: " + eventuallyChangedUri);

      try {
        openAireRecordList.getRecord()
            .add(openAireRecord.getRecordById(eventuallyChangedUri).getRecord());
      } catch (DatatypeConfigurationException e) {
        e.printStackTrace();
      }
    }

    // if (resTokenForResponse != null) {
    // System.out.println("RESTOKEN: ");
    // System.out.println(getResTokenForResponse().getValue());
    // System.out.println(getResumptionToken());
    // resTokenForResponse = OAIPMHUtilities.getResumptionToken(
    // 94146, resumptionToken, cursorCollector, scrollID, this.searchResponseSize, i)
    openAireRecordList.setResumptionToken(getResTokenForResponse());
    // }

    return openAireRecordList;
  }

}
